@@ -1,23 +1,13 @@
 """Parse network devices' configuration and store in database."""
 
-import sys
 import os
+import sys
 
 from loguru import logger
 
-from faddr.rancid import RancidDir
-from faddr.device import Device
-from faddr.device import CiscoIOSDevice
+__version__ = "0.0.4"
 
-
-__version__ = "0.0.3"
-__all__ = (
-    "RancidDir",
-    "Device",
-    "CiscoIOSDevice",
-)
-
-if os.getenv("FADDR_DEBUG"):
+if os.getenv("FADDR_DEBUG") or any(arg in sys.argv for arg in ("-d", "--debug")):
     LOG_LEVEL = "DEBUG"
 else:
     LOG_LEVEL = "INFO"
